#if defined(__CPU_ARC__) /* Do not compile this on AVR based boards */
#include "CurieBLESerial.h"

CurieBLESerial::CurieBLESerial()
{
}

/**
 * Return how many characters are avaliable in the buffer
 */
int CurieBLESerial::available(void)
{
  /* Get number of characters available in serial buffer */
  return _buffer_e - _buffer_s;
}

int CurieBLESerial::peek(void)
{
  return 0;
}

int CurieBLESerial::read(void)
{
  /* "Take" one character from serial buffer*/
  int c = _buffer[_buffer_s];
  _buffer_s++;
  return c;
}

void CurieBLESerial::flush(void)
{
}

size_t CurieBLESerial::write(uint8_t c)
{
  BLECentral central = _peripheral->central();

  if (central && central.connected()) {
    uint8_t tmp[1] = {c};
    _outputCharacteristic->setValue(tmp, 1);
  }
  
  return 0;
}

size_t CurieBLESerial::write(const char *str)
{
  BLECentral central = _peripheral->central();
  
  if (central && central.connected()) {
    int len = strlen(str);
    char temp[20];

    for (int i = 0; i < len; i += 20) {
      int size;
      int n = len - i;

      if (n < 20) {
	strncpy(temp, str + i, n);
	size = n;
      } else {
	strncpy(temp, str + i, 20);
	size = 20;
      }
	
      _outputCharacteristic->setValue((unsigned char *)temp, size);
    }
  }

  return 0;
}

size_t CurieBLESerial::write(const uint8_t *buffer, size_t size)
{
  BLECentral central = _peripheral->central();

  if (central && central.connected()) {
    char temp[20];

    for (size_t i = 0; i < size; i += 20) {
      int send;
      int n = size - i;

      if (n < 20) {
	strncpy(temp, (char *) buffer + i, n);
	send = n;
      } else {
	strncpy(temp, (char *) buffer + i, 20);
	send = 20;
      }

      _outputCharacteristic->setValue((unsigned char *)temp, send);
    }
  }
  
  return 0;
}

void CurieBLESerial::begin(void)
{
  _peripheral = new BLEPeripheral();
  _dataTransferService = new BLEService(SERVICE_UUID);
  _outputCharacteristic = new BLECharacteristic(OUTPUT_UUID, BLENotify | BLERead, 20);
  _inputCharacteristic = new BLECharacteristic(INPUT_UUID, BLEWrite | BLERead, 20);

  _peripheral->setLocalName("arduino101");
  _peripheral->setAdvertisedServiceUuid(SERVICE_UUID);
  _peripheral->addAttribute(*_dataTransferService);
  _peripheral->addAttribute(*_outputCharacteristic);
  _peripheral->addAttribute(*_inputCharacteristic);
  _peripheral->begin();
}

BLECharacteristic *CurieBLESerial::getInputCharacteristic()
{
  return _inputCharacteristic;
}

BLECharacteristic *CurieBLESerial::getOutputCharacteristic()
{
  return _outputCharacteristic;
}

BLEPeripheral *CurieBLESerial::getPeripheral()
{
  return _peripheral;
}

void CurieBLESerial::setBuffer(char *buffer) {
  _buffer_s = 0;
  _buffer_e = _inputCharacteristic->valueLength();
  Serial.println(_buffer_e);
  strncpy(_buffer, buffer, _buffer_e);
}

#endif
