/**
 * This file is part of IoTool Arduino Library.
 * 
 * IoTool Arduino Library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * IoTool Arduino Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with IoTool Arduino Library. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * IoTool Arduino Library demo Sketch.
 * 
 * This Sketch creates one sensor and action. Before sensor and action will be visible
 * in the IoTool app, sync is required. Navigate to IoTool Arduino service preferences
 * to perform sync. Make sure that correct MAC is set before attemping to sync.
 */

#include <IoTool.h>

// Create IoTool object
IoTool ioTool;
// Create IoTool sensor
IoToolSensor mySensor("id", "My Sensor", "My.Sens", "unit");
// Create IoToolAction
IoToolAction myAction("led", "Toggle LED");

// Time keeping variable - used to keep track of last sensor write time.
unsigned long previousNow;

// Action handler
void myActionHandler() {
  // Toggle LED on pin 13
  digitalWrite(13, !digitalRead(13));
}

void setup() {
  // Set pin 13 as output
  pinMode(13, OUTPUT);
  
  // IoTool Library sends data to the service on Android phone using Bluetooth
  // connection. Connect your module to pins 0 (RX) and 1 (TX) on your Arduino.
  // Make sure that Bluetooth module uses exact same baud rate as specified here.
  Serial.begin(57600);
  // Set serial connection on IoTool object, IoTool will use this connection to
  // send and receive data to and from the IoTool Arduino Service.
  ioTool.setSerial(Serial);

  // Add action handler to myAction
  myAction.setHandler(myActionHandler);

  // Add sensor to IoTool object
  ioTool.addSensor(mySensor);

  // Add action to IoTool object
  ioTool.addAction(myAction);
}

void loop() {
  // Execute main loop of the IoTool object
  ioTool.loop();

  // DO NOT use delay function in loop, as it will interfere with IoTool's
  // loop, resulting in unexecuted actions. Use millis() or Timer library
  // (http://playground.arduino.cc/Code/Timer) instead.
  // Check if 200ms has already passed since last sensor write
  if (millis() - previousNow >= 200) {
    // Store last sensor write time
    previousNow = millis();
    // Write random value to the sensor
    int randomValue = random(1024);
    mySensor.write(randomValue);
  }
}
